@@ -3,6 +3,21 @@
 #include <stdlib.h> // for NULL
 #include <R_ext/Rdynload.h>
 
+/*
+The following symbols/expressions for .NAME have been omitted
+
+_DescTools_compute_GCD
+_DescTools_compute_LCM
+_DescTools_n_pow_sum
+_DescTools_conv_DecToBin
+_DescTools_top_n
+_DescTools_bottom_n
+_DescTools_top_i
+_DescTools_bottom_i
+
+Most likely possible values need to be added below.
+*/
+
 /* FIXME:
 Check these declarations against the C/Fortran source code.
 */
@@ -20,6 +35,14 @@ extern void wgt_himed(void *, void *, void *, void *);
 extern void wgt_himed_i(void *, void *, void *, void *);
 
 /* .Call calls */
+extern SEXP _DescTools_bottom_i(SEXP, SEXP);
+extern SEXP _DescTools_bottom_n(SEXP, SEXP);
+extern SEXP _DescTools_compute_GCD(SEXP, SEXP);
+extern SEXP _DescTools_compute_LCM(SEXP, SEXP);
+extern SEXP _DescTools_conv_DecToBin(SEXP);
+extern SEXP _DescTools_n_pow_sum(SEXP);
+extern SEXP _DescTools_top_i(SEXP, SEXP);
+extern SEXP _DescTools_top_n(SEXP, SEXP);
 extern SEXP between_num_(SEXP, SEXP, SEXP);
 extern SEXP between_num_l(SEXP, SEXP, SEXP);
 extern SEXP between_num_lm(SEXP, SEXP, SEXP);
@@ -29,14 +52,6 @@ extern SEXP between_num_m(SEXP, SEXP, SEXP);
 extern SEXP between_num_r(SEXP, SEXP, SEXP);
 extern SEXP between_num_rm(SEXP, SEXP, SEXP);
 extern SEXP conc(SEXP, SEXP, SEXP, SEXP);
-extern SEXP _DescTools_bottom_i(SEXP, SEXP);
-extern SEXP _DescTools_bottom_n(SEXP, SEXP);
-extern SEXP _DescTools_compute_GCD(SEXP, SEXP);
-extern SEXP _DescTools_compute_LCM(SEXP, SEXP);
-extern SEXP _DescTools_conv_DecToBin(SEXP);
-extern SEXP _DescTools_n_pow_sum(SEXP);
-extern SEXP _DescTools_top_i(SEXP, SEXP);
-extern SEXP _DescTools_top_n(SEXP, SEXP);
 extern SEXP pip(SEXP, SEXP, SEXP, SEXP, SEXP, SEXP);
 extern SEXP rkurt(SEXP, SEXP);
 extern SEXP rskew(SEXP, SEXP);
@@ -62,27 +77,27 @@ static const R_CMethodDef CEntries[] = {
 };
 
 static const R_CallMethodDef CallEntries[] = {
-  {"between_num_",            (DL_FUNC) &between_num_,            3},
-  {"between_num_l",           (DL_FUNC) &between_num_l,           3},
-  {"between_num_lm",          (DL_FUNC) &between_num_lm,          3},
-  {"between_num_lr",          (DL_FUNC) &between_num_lr,          3},
-  {"between_num_lrm",         (DL_FUNC) &between_num_lrm,         3},
-  {"between_num_m",           (DL_FUNC) &between_num_m,           3},
-  {"between_num_r",           (DL_FUNC) &between_num_r,           3},
-  {"between_num_rm",          (DL_FUNC) &between_num_rm,          3},
-  {"conc",                    (DL_FUNC) &conc,                    4},
-  {"_DescTools_bottom_i",     (DL_FUNC) &_DescTools_bottom_i,      2},
-  {"_DescTools_bottom_n",     (DL_FUNC) &_DescTools_bottom_n,      2},
-  {"_DescTools_compute_GCD",  (DL_FUNC) &_DescTools_compute_GCD,   2},
-  {"_DescTools_compute_LCM",  (DL_FUNC) &_DescTools_compute_LCM,   2},
-  {"_DescTools_conv_DecToBin",(DL_FUNC) &_DescTools_conv_DecToBin, 1},
-  {"_DescTools_n_pow_sum",    (DL_FUNC) &_DescTools_n_pow_sum,     1},
-  {"_DescTools_top_i",        (DL_FUNC) &_DescTools_top_i,         2},
-  {"_DescTools_top_n",        (DL_FUNC) &_DescTools_top_n,         2},
-  {"pip",                     (DL_FUNC) &pip,                     6},
-  {"rkurt",                   (DL_FUNC) &rkurt,                   2},
-  {"rskew",                   (DL_FUNC) &rskew,                   2},
-  {"tbrm",                    (DL_FUNC) &tbrm,                    2},
+  {"_DescTools_bottom_i",      (DL_FUNC) &_DescTools_bottom_i,      2},
+  {"_DescTools_bottom_n",      (DL_FUNC) &_DescTools_bottom_n,      2},
+  {"_DescTools_compute_GCD",   (DL_FUNC) &_DescTools_compute_GCD,   2},
+  {"_DescTools_compute_LCM",   (DL_FUNC) &_DescTools_compute_LCM,   2},
+  {"_DescTools_conv_DecToBin", (DL_FUNC) &_DescTools_conv_DecToBin, 1},
+  {"_DescTools_n_pow_sum",     (DL_FUNC) &_DescTools_n_pow_sum,     1},
+  {"_DescTools_top_i",         (DL_FUNC) &_DescTools_top_i,         2},
+  {"_DescTools_top_n",         (DL_FUNC) &_DescTools_top_n,         2},
+  {"between_num_",             (DL_FUNC) &between_num_,             3},
+  {"between_num_l",            (DL_FUNC) &between_num_l,            3},
+  {"between_num_lm",           (DL_FUNC) &between_num_lm,           3},
+  {"between_num_lr",           (DL_FUNC) &between_num_lr,           3},
+  {"between_num_lrm",          (DL_FUNC) &between_num_lrm,          3},
+  {"between_num_m",            (DL_FUNC) &between_num_m,            3},
+  {"between_num_r",            (DL_FUNC) &between_num_r,            3},
+  {"between_num_rm",           (DL_FUNC) &between_num_rm,           3},
+  {"conc",                     (DL_FUNC) &conc,                     4},
+  {"pip",                      (DL_FUNC) &pip,                      6},
+  {"rkurt",                    (DL_FUNC) &rkurt,                    2},
+  {"rskew",                    (DL_FUNC) &rskew,                    2},
+  {"tbrm",                     (DL_FUNC) &tbrm,                     2},
   {NULL, NULL, 0}
 };
 
